#ifndef REQUESTDLG_H
#define REQUESTDLG_H

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <qpushbutton.h>
#include <qradiobutton.h>
#include <qdialog.h>
#include <qgroupbox.h>
#include <qbuttongroup.h>

#include "mledit.h"


class RequestDlg : public QDialog
{
   Q_OBJECT
public:
   RequestDlg(QWidget *parent = NULL, char *name = NULL);
   const char *reason(void);
protected:
   QGroupBox *boxReason;
   MLEditWrap *mleReason;
   QButtonGroup *grpReturn;
   QRadioButton *rdbAccept, *rdbRefuse;
   QPushButton *btnOk;
protected slots:
   void done();
};

#endif
